@@ -11,6 +11,8 @@
 #include "eog-image-list.h"
 #include "libeog-marshal.h"
 
+#define DEBUG_IMAGE_LIST 0 
+
 struct  _EogIter {
 	/* age of the image list when the iterator was created */
 	unsigned int   age;
@@ -158,7 +160,7 @@ eog_image_list_dispose (GObject *object)
 }
 
 static void
-eog_image_list_instance_init (EogImageList *obj)
+eog_image_list_init (EogImageList *obj)
 {
 	EogImageListPrivate *priv;
 
@@ -220,10 +222,7 @@ eog_image_list_class_init (EogImageListClass *klass)
 }
 
 
-GNOME_CLASS_BOILERPLATE (EogImageList,
-			 eog_image_list,
-			 GObject,
-			 G_TYPE_OBJECT)
+G_DEFINE_TYPE (EogImageList, eog_image_list, G_TYPE_OBJECT)
 
 
 /* ================== Private EogImageList functions  ===================*/
@@ -457,7 +456,7 @@ vfs_monitor_dir_cb (GnomeVFSMonitorHandle *handle,
 	EogImage *image = NULL;
 	GList *node=NULL;
 	gboolean found = FALSE;
-	
+
 	cleanup_dead_files (list);
 	
 	switch (event_type) {
@@ -749,6 +748,7 @@ eog_image_list_get_base_uri (EogImageList *list)
 void
 eog_image_list_print_debug (EogImageList *list)
 {
+#if DEBUG_IMAGE_LIST
 	GList *it;
 	EogImageListPrivate *priv;
 	int i = 1;
@@ -768,6 +768,7 @@ eog_image_list_print_debug (EogImageList *list)
 		
 		g_free (uri_str);
 	}
+#endif
 }
 
 void
